==> academy-user-core-2.2.0-sources.jar: com/ptteng/academy/user/model/CooperatorOrder.java <==
package com.ptteng.academy.user.model;

import java.io.Serializable;

public class CooperatorOrder implements Serializable{
    private static final long serialVersionUID = 53390427115066816L;
    private Long id;
    private double price;
    private Long time;
    private String type;
    private String username;
    private String orderName;
    private double memberMoney;
    private double lessonMoney;
    private double totalMoney;
    private Integer lessonOrderNumber;
    private Integer memberOrderNumber;

    @Override
    public String toString() {
        return "CooperatorOrder{" +
                "id=" + id +
                ", price=" + price +
                ", time=" + time +
                ", type='" + type + '\'' +
                ", username='" + username + '\'' +
                ", orderName='" + orderName + '\'' +
                ", memberMoney=" + memberMoney +
                ", lessonMoney=" + lessonMoney +
                ", totalMoney=" + totalMoney +
                ", lessonOrderNumber=" + lessonOrderNumber +
                ", memberOrderNumber=" + memberOrderNumber +
                '}';
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public Integer getLessonOrderNumber() {
        return lessonOrderNumber;
    }

    public void setLessonOrderNumber(Integer lessonOrderNumber) {
        this.lessonOrderNumber = lessonOrderNumber;
    }

    public Integer getMemberOrderNumber() {
        return memberOrderNumber;
    }

    public void setMemberOrderNumber(Integer memberOrderNumber) {
        this.memberOrderNumber = memberOrderNumber;
    }

    public double getTotalMoney() {
        return totalMoney;
    }

    public void setTotalMoney(double totalMoney) {
        this.totalMoney = totalMoney;
    }



    public double getMemberMoney() {
        return memberMoney;
    }

    public void setMemberMoney(double memberMoney) {
        this.memberMoney = memberMoney;
    }

    public double getLessonMoney() {
        return lessonMoney;
    }

    public void setLessonMoney(double lessonMoney) {
        this.lessonMoney = lessonMoney;
    }

    public String getOrderName() {
        return orderName;
    }

    public void setOrderName(String orderName) {
        this.orderName = orderName;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public double getPrice() {
        return price;
    }

    public void setPrice(double price) {
        this.price = price;
    }

    public Long getTime() {
        return time;
    }

    public void setTime(Long time) {
        this.time = time;
    }

}

==> academy-user-core-2.2.4-sources.jar: com/ptteng/academy/user/model/CooperatorOrder.java <==
package com.ptteng.academy.user.model;

import java.io.Serializable;

public class CooperatorOrder implements Serializable{
    private static final long serialVersionUID = 53390427115066816L;
    private Long id;
    private double price;
    private Long time;
    private String type;
    private String username;
    private String alias;
    private String orderName;
    private double memberMoney;
    private double lessonMoney;
    private double totalMoney;
    private Integer lessonOrderNumber;
    private Integer memberOrderNumber;

    @Override
    public String toString() {
        return "CooperatorOrder{" +
                "id=" + id +
                ", price=" + price +
                ", time=" + time +
                ", type='" + type + '\'' +
                ", username='" + username + '\'' +
                ", alias='" + alias + '\'' +
                ", orderName='" + orderName + '\'' +
                ", memberMoney=" + memberMoney +
                ", lessonMoney=" + lessonMoney +
                ", totalMoney=" + totalMoney +
                ", lessonOrderNumber=" + lessonOrderNumber +
                ", memberOrderNumber=" + memberOrderNumber +
                '}';
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public Integer getLessonOrderNumber() {
        return lessonOrderNumber;
    }

    public void setLessonOrderNumber(Integer lessonOrderNumber) {
        this.lessonOrderNumber = lessonOrderNumber;
    }

    public Integer getMemberOrderNumber() {
        return memberOrderNumber;
    }

    public void setMemberOrderNumber(Integer memberOrderNumber) {
        this.memberOrderNumber = memberOrderNumber;
    }

    public double getTotalMoney() {
        return totalMoney;
    }

    public void setTotalMoney(double totalMoney) {
        this.totalMoney = totalMoney;
    }



    public double getMemberMoney() {
        return memberMoney;
    }

    public void setMemberMoney(double memberMoney) {
        this.memberMoney = memberMoney;
    }

    public double getLessonMoney() {
        return lessonMoney;
    }

    public void setLessonMoney(double lessonMoney) {
        this.lessonMoney = lessonMoney;
    }

    public String getOrderName() {
        return orderName;
    }

    public void setOrderName(String orderName) {
        this.orderName = orderName;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public double getPrice() {
        return price;
    }

    public void setPrice(double price) {
        this.price = price;
    }

    public Long getTime() {
        return time;
    }

    public void setTime(Long time) {
        this.time = time;
    }

    public String getAlias() {
        return alias;
    }

    public void setAlias(String alias) {
        this.alias = alias;
    }
}
